@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,21 +13,29 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.workflows import gapic_version as package_version
+
+__version__ = package_version.__version__
+
 
 from google.cloud.workflows_v1.services.workflows.async_client import (
     WorkflowsAsyncClient,
 )
 from google.cloud.workflows_v1.services.workflows.client import WorkflowsClient
-from google.cloud.workflows_v1.types.workflows import CreateWorkflowRequest
-from google.cloud.workflows_v1.types.workflows import DeleteWorkflowRequest
-from google.cloud.workflows_v1.types.workflows import GetWorkflowRequest
-from google.cloud.workflows_v1.types.workflows import ListWorkflowsRequest
-from google.cloud.workflows_v1.types.workflows import ListWorkflowsResponse
-from google.cloud.workflows_v1.types.workflows import OperationMetadata
-from google.cloud.workflows_v1.types.workflows import UpdateWorkflowRequest
-from google.cloud.workflows_v1.types.workflows import Workflow
+from google.cloud.workflows_v1.types.workflows import (
+    CreateWorkflowRequest,
+    DeleteWorkflowRequest,
+    GetWorkflowRequest,
+    ListWorkflowsRequest,
+    ListWorkflowsResponse,
+    OperationMetadata,
+    UpdateWorkflowRequest,
+    Workflow,
+)
 
 __all__ = (
+    "WorkflowsClient",
+    "WorkflowsAsyncClient",
     "CreateWorkflowRequest",
     "DeleteWorkflowRequest",
     "GetWorkflowRequest",
@@ -37,6 +44,4 @@ __all__ = (
     "OperationMetadata",
     "UpdateWorkflowRequest",
     "Workflow",
-    "WorkflowsAsyncClient",
-    "WorkflowsClient",
 )
