@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,6 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.workflows.executions import gapic_version as package_version
+
+__version__ = package_version.__version__
+
 
 from google.cloud.workflows.executions_v1.services.executions.async_client import (
     ExecutionsAsyncClient,
@@ -21,22 +24,24 @@ from google.cloud.workflows.executions_v1.services.executions.async_client impor
 from google.cloud.workflows.executions_v1.services.executions.client import (
     ExecutionsClient,
 )
-from google.cloud.workflows.executions_v1.types.executions import CancelExecutionRequest
-from google.cloud.workflows.executions_v1.types.executions import CreateExecutionRequest
-from google.cloud.workflows.executions_v1.types.executions import Execution
-from google.cloud.workflows.executions_v1.types.executions import ExecutionView
-from google.cloud.workflows.executions_v1.types.executions import GetExecutionRequest
-from google.cloud.workflows.executions_v1.types.executions import ListExecutionsRequest
-from google.cloud.workflows.executions_v1.types.executions import ListExecutionsResponse
+from google.cloud.workflows.executions_v1.types.executions import (
+    CancelExecutionRequest,
+    CreateExecutionRequest,
+    Execution,
+    ExecutionView,
+    GetExecutionRequest,
+    ListExecutionsRequest,
+    ListExecutionsResponse,
+)
 
 __all__ = (
+    "ExecutionsClient",
+    "ExecutionsAsyncClient",
     "CancelExecutionRequest",
     "CreateExecutionRequest",
     "Execution",
-    "ExecutionView",
-    "ExecutionsAsyncClient",
-    "ExecutionsClient",
     "GetExecutionRequest",
     "ListExecutionsRequest",
     "ListExecutionsResponse",
+    "ExecutionView",
 )
