@@ -17,7 +17,7 @@
 import dataclasses
 import json  # type: ignore
 import re
-from typing import Callable, Dict, List, Optional, Sequence, Tuple, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 import warnings
 
 from google.api_core import (
@@ -378,7 +378,7 @@ class WorkflowsRestTransport(WorkflowsTransport):
         def __hash__(self):
             return hash("CreateWorkflow")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {
             "workflowId": "",
         }
 
@@ -405,7 +405,6 @@ class WorkflowsRestTransport(WorkflowsTransport):
                     The request object. Request for the
                 [CreateWorkflow][google.cloud.workflows.v1.Workflows.CreateWorkflow]
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -479,7 +478,7 @@ class WorkflowsRestTransport(WorkflowsTransport):
         def __hash__(self):
             return hash("DeleteWorkflow")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -504,7 +503,6 @@ class WorkflowsRestTransport(WorkflowsTransport):
                     The request object. Request for the
                 [DeleteWorkflow][google.cloud.workflows.v1.Workflows.DeleteWorkflow]
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -569,7 +567,7 @@ class WorkflowsRestTransport(WorkflowsTransport):
         def __hash__(self):
             return hash("GetWorkflow")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -594,7 +592,6 @@ class WorkflowsRestTransport(WorkflowsTransport):
                     The request object. Request for the
                 [GetWorkflow][google.cloud.workflows.v1.Workflows.GetWorkflow]
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -660,7 +657,7 @@ class WorkflowsRestTransport(WorkflowsTransport):
         def __hash__(self):
             return hash("ListWorkflows")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -685,7 +682,6 @@ class WorkflowsRestTransport(WorkflowsTransport):
                     The request object. Request for the
                 [ListWorkflows][google.cloud.workflows.v1.Workflows.ListWorkflows]
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -752,7 +748,7 @@ class WorkflowsRestTransport(WorkflowsTransport):
         def __hash__(self):
             return hash("UpdateWorkflow")
 
-        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, Any] = {}
 
         @classmethod
         def _get_unset_required_fields(cls, message_dict):
@@ -777,7 +773,6 @@ class WorkflowsRestTransport(WorkflowsTransport):
                     The request object. Request for the
                 [UpdateWorkflow][google.cloud.workflows.v1.Workflows.UpdateWorkflow]
                 method.
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
